@@ -8,7 +8,7 @@ from rich.console import RenderableType
 
 if TYPE_CHECKING:
     from nonechat.app import Frontend
-    from nonechat.storage import Storage, StateChange
+    from nonechat.model import StateChange
 
 
 MAX_LINES = 1000
@@ -28,25 +28,21 @@ class LogPanel(Widget):
 
     def __init__(self) -> None:
         super().__init__()
-
         self.output = RichLog(max_lines=MAX_LINES, min_width=60, wrap=True, markup=True)
-        # if setting.bg_color:
-        #     self.styles.background = setting.bg_color
-        #     self.output.styles.background = setting.bg_color
 
     @property
-    def storage(self) -> "Storage":
-        return cast("Frontend", self.app).storage
+    def app(self) -> "Frontend":
+        return cast("Frontend", super().app)
 
     def compose(self):
         yield self.output
 
     def on_mount(self):
-        self.on_log(self.storage.log_history)
-        self.storage.add_log_watcher(self)
+        self.on_log(self.app.log_store.log_history)
+        self.app.log_store.add_log_watcher(self)
 
     def on_unmount(self, event: Unmount):
-        self.storage.remove_log_watcher(self)
+        self.app.log_store.remove_log_watcher(self)
 
     def on_state_change(self, event: "StateChange[tuple[RenderableType, ...]]") -> None:
         self.on_log(event.data)
