@@ -1,10 +1,15 @@
 from datetime import datetime
+from typing import Generic, TypeVar
 from dataclasses import field, dataclass
 
+from textual.message import Message
+
 from .message import ConsoleMessage
 
+T = TypeVar("T")
 
-@dataclass(frozen=True, eq=True)
+
+@dataclass(eq=True, unsafe_hash=True)
 class User:
     """用户"""
 
@@ -12,8 +17,10 @@ class User:
     avatar: str = field(default="👤")
     nickname: str = field(default="User")
 
+    _created_at: datetime = field(default_factory=datetime.now, init=False)
 
-@dataclass(frozen=True, eq=True)
+
+@dataclass(eq=True, unsafe_hash=True)
 class Robot(User):
     """机器人"""
 
@@ -21,14 +28,16 @@ class Robot(User):
     nickname: str = field(default="Bot")
 
 
-@dataclass(frozen=True, eq=True)
+@dataclass(eq=True, unsafe_hash=True)
 class Channel:
     """频道信息"""
 
     id: str
     name: str
     description: str = ""
-    emoji: str = "💬"
+    avatar: str = "💬"
+
+    _created_at: datetime = field(default_factory=datetime.now, init=False)
 
 
 @dataclass
@@ -42,4 +51,14 @@ class Event:
 
 @dataclass
 class MessageEvent(Event):
+    message_id: str
     message: ConsoleMessage
+
+
+DIRECT = Channel("_direct", "私聊", "私聊频道", "🔏")
+
+
+class StateChange(Message, Generic[T], bubble=False):
+    def __init__(self, data: T) -> None:
+        super().__init__()
+        self.data = data
